function init() {
    // Initialize audio
    context = new webkitAudioContext();
    
    // Create post-compressor gain node.
    postCompressorGain = context.createGainNode();
    postCompressorGain.gain.value = 1.4;

    postCompressorGain.connect(context.destination);

    if (context.createDynamicsCompressor) {
        // Create dynamics compressor to sweeten the overall mix.
        compressor = context.createDynamicsCompressor();
        compressor.connect(postCompressorGain);
    } else {
        // Compressor is not available on this implementation - bypass and simply point to destination.
        compressor = postCompressorGain;
    }
       
    // Create sources
    source1 = context.createBufferSource();
    source2 = context.createBufferSource();
    
    // Create gain nodes to control the volume for the two sources.
    source1Gain = context.createGainNode();
    source2Gain = context.createGainNode();
    
    // Create pre-compressor gain node.
    preCompressorGain = context.createGainNode();
    preCompressorGain.gain.value = 0.4;
    
    
    preCompressorGain.connect(compressor);

    // Create gain nodes to control the wet (effect) mix levels for left/right
    wetGainNode1 = context.createGainNode();
    wetGainNode2 = context.createGainNode();
    wetGainNode1.gain.value = 0.0;
    wetGainNode2.gain.value = 0.0;

    // Create a lowpass resonant filter for both left and right
    lowFilter1 = context.createBiquadFilter();
    lowFilter2 = context.createBiquadFilter();
    lowFilter1.frequency.value = 22050.0;
    lowFilter2.frequency.value = 22050.0;
    lowFilter1.Q.value = 5.0; // in decibels
    lowFilter2.Q.value = 5.0; // in decibels

    // Create a convolver for a rhythm effect
    convolver = context.createConvolver();

    // Connect sources to gain and filter nodes.
    source1.connect(source1Gain);
    source2.connect(source2Gain);
    source1Gain.connect(lowFilter1);
    source2Gain.connect(lowFilter2);

    // Connect dry mix
    lowFilter1.connect(preCompressorGain);
    lowFilter2.connect(preCompressorGain);

    // Connect wet (effect) mix
    lowFilter1.connect(wetGainNode1);
    wetGainNode1.connect(convolver);
    lowFilter2.connect(wetGainNode2);    
    wetGainNode2.connect(convolver);
    convolver.connect(preCompressorGain);

    // Start out with cross-fader at center position (equal-power crossfader)
    source1Gain.gain.value = 0.707;
    source2Gain.gain.value = 0.707;

    source1.looping = true;
    source2.looping = true;

    // load reverb
    // setReverbImpulseResponse('impulse-responses/spatialized3.wav');
    //setReverbImpulseResponse('snd/fx_marimbo.wav');

    bufferLoader1 = new BufferLoader(source1, "snd/sound3.wav");
    bufferLoader2 = new BufferLoader(source2, "snd/sound4.wav");

    bufferLoader1.load();
    bufferLoader2.load();
}